package
Version:
v0.0.0-...-8352b7d
Opens a new window with list of versions in this module.
Published: Jul 8, 2020
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type As interface {
As(other interface{}) bool
}
type Is interface {
Is(other interface{}) bool
}
type Unwrap interface {
Unwrap() (interface{}, bool)
}
type Wrap interface {
Wrap(v interface{}) bool
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.